@@ -18,6 +18,9 @@ OFFLINE_MC_TRACK_USR = OfflineReader(
     )
 )
 OFFLINE_NUMUCC = OfflineReader(data_path("offline/numucc.root"))  # with mc data
+OFFLINE_MC_TRACK = OfflineReader(
+    data_path("gseagen/gseagen_v7.0.0_numuCC_diffuse.aa.root")
+)
 
 
 class TestOfflineReader(unittest.TestCase):
@@ -102,15 +105,40 @@ class TestHeader(unittest.TestCase):
         head = {
             "a": "1 2 3",
             "b+c": "4 5 6",
+            "c": "foo",
+            "d": "7",
+            "e+f": "bar",
         }
 
         header = Header(head)
         assert 1 == header["a"][0]
         assert 2 == header["a"][1]
         assert 3 == header["a"][2]
+        assert 1 == header.a[0]
+        assert 2 == header.a[1]
+        assert 3 == header.a[2]
         assert 4 == header["b+c"][0]
         assert 5 == header["b+c"][1]
         assert 6 == header["b+c"][2]
+        assert "foo" == header.c
+        assert "foo" == header["c"]
+        assert 7 == header.d
+        assert 7 == header["d"]
+        assert "bar" == header["e+f"]
+
+    def test_header_behaves_like_a_dict(self):
+        head = {
+            "a": "1 2 3",
+            "b+c": "4 5 6",
+            "c": "foo",
+            "d": "7",
+            "e+f": "bar",
+        }
+
+        header = Header(head)
+        self.assertListEqual(list(head.keys()), list(header.keys()))
+        assert 5 == len(header.values())
+        assert 5 == len(header.items())
 
     def test_reading_header_from_sample_file(self):
         head = OFFLINE_NUMUCC.header
@@ -387,7 +415,11 @@ class TestOfflineTracks(unittest.TestCase):
         self.f = OFFLINE_FILE
         self.tracks = OFFLINE_FILE.events.tracks
         self.tracks_numucc = OFFLINE_NUMUCC
+        self.mc_tracks = OFFLINE_MC_TRACK.mc_tracks
+        self.mc_tracks_old = OFFLINE_MC_TRACK_USR.mc_tracks
         self.n_events = 10
+        self.status = [100, 5, 11, 15, 1, 12, 12, 12, 12, 12]
+        self.mother_id = [-1, -1, 1, 1, 0, 2, 5, 5, 6, 8]
 
     def test_fields(self):
         for field in [
@@ -408,6 +440,18 @@ class TestOfflineTracks(unittest.TestCase):
         ]:
             getattr(self.tracks, field)
 
+    def test_status(self):
+        assert np.allclose(self.status, self.mc_tracks[1].status[:10].tolist())
+
+    def test_mother_id(self):
+        assert np.allclose(self.mother_id, self.mc_tracks[1].mother_id[:10].tolist())
+
+    def test_attribute_error_raised_for_older_files(self):
+        with self.assertRaises(AttributeError):
+            self.mc_tracks_old[1].mother_id
+        with self.assertRaises(AttributeError):
+            self.mc_tracks_old[1].status
+
     def test_item_selection(self):
         self.assertListEqual(
             list(self.tracks[0].dir_z[:2]), [-0.872885221293917, -0.872885221293917]
